@@ -64,7 +64,7 @@ class Vault:
     def open(self) -> bool:
         """Open and read the Vault file"""
         try:
-            self._check_backup()
+            self._sanity_check()
             self.passphrase = self._read_passphrase()
             if not self._is_open:
                 self._unlock_vault()
@@ -232,7 +232,7 @@ class Vault:
         self._is_open = True
         safe_del_file(self.configs.vault_file)
 
-    def _check_backup(self) -> None:
+    def _sanity_check(self) -> None:
         """Check existing vault backups and apply a rollback if required."""
         vault_file = self.configs.vault_file
         unlocked_vault_file = self.configs.unlocked_vault_file
